<?php
if ( !defined( 'ABSPATH' ) )
	die( 'Direct access forbidden.' );

/**
 * Creates widget with recent post thumbnail
 */
class Charitious_recent_post extends WP_Widget {

	function __construct() {

		$widget_opt = array(
			'classname'		 => 'charitious_widget',
			'description'	 => 'Recent Post With Thumbnail'
		);

		parent::__construct( 'xs-recent-post', esc_html__( 'Charitious Recent Post', 'charitious' ), $widget_opt );
	}

	function widget( $args, $instance ) {

		global $wp_query;

		echo charitious_return($args[ 'before_widget' ]);

		if ( !empty( $instance[ 'title' ] ) ) {

			echo charitious_return($args[ 'before_title' ]) . apply_filters( 'widget_title', $instance[ 'title' ] ) . charitious_return($args[ 'after_title' ]);
		}

		if ( !empty( $instance[ 'number_of_posts' ] ) ) {
			$no_of_post = $instance[ 'number_of_posts' ];
		} else {
			$no_of_post = 3;
		}


		$query = array(
			'post_type'		 => array( 'post' ),
			'post_status'	 => array( 'publish' ),
			'orderby'		 => 'date',
			'order'			 => 'DESC',
			'posts_per_page' => $no_of_post
		);

		$loop = new WP_Query( $query );
		?>
        <ul class="xs-recent-post-widget">
			<?php
            $count = 1;
			if ( $loop->have_posts() ):
				while ( $loop->have_posts() ):
					$loop->the_post();

					?>
					<li>
                        <div class="posts-thumb float-left">
                            <?php
                            $thumbnail	 = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), '' );
                            $img  = xs_resize( $thumbnail[ 0 ], 70, 50,true );
                            if($img):
                            ?>
                            <a href="<?php echo get_the_permalink();?>">
                                <img alt="<?php echo get_the_title();?>" class="img-responsive" src="<?php echo esc_url( $img );?>">
                            </a>
                            <?php endif; ?>
                        </div>
                        <div class="post-info">
                            <h4 class="entry-title">
								<a href="<?php echo get_the_permalink(); ?>"><?php echo wp_trim_words( get_the_title(), 3, '' );?></a>
                            </h4>
                            <div class="post-meta">
                                <span class="comments-link">
                                    <i class="fa fa-calendar"></i>
                                    <a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_date();?></a>
                                </span>
                            </div>
                        </div>
					</li>
				<?php endwhile; ?>
			<?php else: ?>
				<div class="nopost_message">
					<p><?php echo esc_html__( 'No Post Available', 'charitious' ) ?></p>';
				</div>
			<?php endif; ?>  
		</ul>
		<?php
		wp_reset_postdata();
		echo charitious_return($args[ 'after_widget' ]);
	}

	function update( $new_instance, $old_instance ) {

		$old_instance[ 'title' ]			 = strip_tags( $new_instance[ 'title' ] );
		$old_instance[ 'number_of_posts' ] = $new_instance[ 'number_of_posts' ];

		return $old_instance;
	}

	function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		} else {
			$title = esc_html__( 'Recent Posts', 'charitious' );
		}
		if ( isset( $instance[ 'number_of_posts' ] ) ) {
			$no_of_post = $instance[ 'number_of_posts' ];
		} else {
			$no_of_post = 3;
		}
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'charitious' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_of_posts' ) ); ?>"><?php esc_html_e( 'Number Of Posts:', 'charitious' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_of_posts' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_of_posts' ) ); ?>" type="text" value="<?php echo esc_attr( $no_of_post ); ?>" />
		</p>
		<?php
	}

}
